@@ -2,7 +2,7 @@ package Resource::Silo::Metadata;
 
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 NAME
 
@@ -20,11 +20,13 @@ See also L<Resource::Silo/meta>.
 =cut
 
 use Carp;
+use Module::Load qw( load );
 use Scalar::Util qw( looks_like_number reftype );
 use Sub::Quote qw( quote_sub );
 
 my $BARE_REX = '[a-z][a-z_0-9]*';
-my $ID_REX   = qr(^$BARE_REX$);
+my $ID_REX   = qr(^$BARE_REX$)i;
+my $MOD_REX  = qr(^$BARE_REX(?:::$BARE_REX)*$)i;
 
 # Define possible reftypes portably
 my $CODE   = reftype sub { };
@@ -62,6 +64,7 @@ my %known_args = (
     ignore_cache    => 1,
     init            => 1,
     preload         => 1,
+    require         => 1,
 );
 sub add {
     my $self = shift;
@@ -84,6 +87,19 @@ sub add {
     croak "resource '$name': unknown arguments in specification: @extra"
         if @extra;
 
+    {
+        # validate 'require' before 'class'
+        if (!ref $spec{require}) {
+            $spec{require} = defined $spec{require} ? [ $spec{require} ] : [];
+        };
+        croak "resource '$name': 'require' must be a module name or a list thereof"
+            unless ref $spec{require} eq 'ARRAY';
+        my @bad = grep { $_ !~ $MOD_REX } @{ $spec{require} };
+        croak "resource '$name': 'require' doesn't look like module name(s): "
+            .join ", ", map { "'$_'" } @bad
+                if @bad;
+    };
+
     _make_init_class($self, $name, \%spec)
         if (defined $spec{class});
 
@@ -151,7 +167,7 @@ sub _make_init_class {
     $spec->{dependencies} //= {};
 
     croak "resource '$name': 'class' doesn't look like a package name: '$class'"
-        unless $class =~ /^$BARE_REX(?:::$BARE_REX)*$/i;
+        unless $class =~ $MOD_REX;
     defined $spec->{$_} and croak "resource '$name': 'class' is incompatible with '$_'"
         for qw(init argument);
     croak "resource '$name': 'class' requires 'dependencies' to be a hash"
@@ -159,9 +175,11 @@ sub _make_init_class {
 
     my %deps = %{ $spec->{dependencies} };
 
+    push @{ $spec->{require} }, $class;
+
     my %pass_args;
     my @realdeps;
-    my @body = ("my \$c = shift;", "require $class;", "$class->new(" );
+    my @body = ("my \$c = shift;", "$class->new(" );
 
     # format: constructor_arg => [ resource_name, resource_arg ]
     foreach my $key (keys %deps) {
@@ -227,6 +245,52 @@ sub list {
     return wantarray ? @list : \@list;
 };
 
+=head2 self_check()
+
+Check setup validity. Dies on errors, return C<$self> otherwise.
+
+The following checks are available so far:
+
+=over
+
+=item * dependencies must be defined;
+
+=item * required modules must be loadable.
+
+=back
+
+B<EXPERIMENTAL>. Interface & performed checks may change in the future.
+
+=cut
+
+sub self_check {
+    my $self = shift;
+
+    my $res = $self->{resource};
+    foreach my $name (sort keys %$res) {
+        my $entry = $res->{$name};
+
+        my @missing_deps = grep { !$res->{$_} } keys %{ $entry->{allowdeps} };
+        croak "resource '$name': missing dependencies: ".
+            join ", ", map { "'$_'" } @missing_deps
+                if @missing_deps;
+
+        local $@;
+        my $mod;
+        eval {
+            foreach ( @{ $entry->{require} } ) {
+                $mod = $_;
+                load $mod;
+            };
+            1;
+        } || do {
+            croak "resource '$name': failed to load required module '$mod': $@";
+        };
+    };
+
+    return $self;
+};
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2023, Konstantin Uvarin, C<< <khedin@gmail.com> >>
